"use strict";
/*
 * Copyright 2019 Dynatrace LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidHttpUrl = exports.isNode = exports.getVersionNumber = exports.isInteger = exports.isFinite = exports.timeout = exports.truncate = exports.removeElement = void 0;
/**
 * Maximum size of all values passed to Dynatrace.
 */
const MAX_VALUE_LENGTH = 250;
/**
 * Removes an element from a given array.
 * If there are multiple elements of the same instance, only the first is removed.
 *
 * @param array The array to search in
 * @param element The element to remove.
 */
const removeElement = (array, element) => {
    const index = array.indexOf(element);
    if (index < 0) {
        return;
    }
    array.splice(index, 1);
};
exports.removeElement = removeElement;
const truncate = (str, maxLength = MAX_VALUE_LENGTH) => str.substr(0, maxLength);
exports.truncate = truncate;
const timeout = (milliseconds) => new Promise((res) => {
    setTimeout(res, milliseconds);
});
exports.timeout = timeout;
const isFinite = (n) => typeof n === 'number' && n !== Infinity && n !== -Infinity && !isNaN(n);
exports.isFinite = isFinite;
const isInteger = (n) => Number.isSafeInteger(n) && String(n).indexOf('.') === -1;
exports.isInteger = isInteger;
/**
 * Returns the correct version string for OpenKit that is used in the basic data
 *
 * @param major Major version which should be reported
 * @param sprint Sprint version which should be reported
 * @param version Current OK version which should be used for calculating version string
 * @returns Version string which will be used in basic data e.g. 8.205.20100
 */
const getVersionNumber = (major, sprint, version) => {
    const versionString = version.major * 10000 + version.minor * 100 + version.build;
    return `${major}.${sprint}.${versionString}`;
};
exports.getVersionNumber = getVersionNumber;
exports.isNode = typeof process !== 'undefined' &&
    // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
    process.release &&
    process.release.name === 'node';
const isValidHttpUrl = (url) => {
    try {
        new URL(url);
        return true;
    }
    catch (_) {
        return false;
    }
};
exports.isValidHttpUrl = isValidHttpUrl;
//# sourceMappingURL=Utils.js.map