import { StatusRequest } from './StatusRequest';
import { StatusResponse } from './StatusResponse';
/**
 * Interface for the communication between OpenKit and Dynatrace.
 */
export interface CommunicationChannel {
    /**
     * Send a status request to the dynatrace server.
     *
     * @param url The url for the active gate.
     * @param request The request parameters for the status request.
     * @returns A status response.
     */
    sendStatusRequest(url: string, request: StatusRequest): Promise<StatusResponse>;
    /**
     * Send a new session request to the dynatrace server.
     *
     * @param url The url for the active gate.
     * @param request The request parameters for the status request.
     * @returns A status response
     */
    sendNewSessionRequest(url: string, request: StatusRequest): Promise<StatusResponse>;
    /**
     * Send payload data to the dynatrace server.
     *
     * @param url The url for the active gate.
     * @param request The request parameters for the status request.
     * @param query The query which should be send to the server.
     * @returns A status response.
     */
    sendPayloadData(url: string, request: StatusRequest, query: string): Promise<StatusResponse>;
}
//# sourceMappingURL=CommunicationChannel.d.ts.map