/**
 * Flag to check if capturing for certain parts is enabled or not.
 */
export declare enum CaptureMode {
    On = 0,
    Off = 1
}
/**
 * Represents a status response from dynatrace which will update the state of the current OpenKit application.
 */
export interface StatusResponse {
    /**
     * If captureMode = Off, all communication should be stopped and no further communication is allowed.
     */
    readonly captureMode?: CaptureMode;
    /**
     * The server id where the next request should be send to.
     */
    readonly serverId?: number;
    /**
     * The maximum beacon size in kilobyte.
     */
    readonly maxBeaconSizeInKb?: number;
    /**
     * Flag if errors should be captured.
     */
    readonly captureErrors?: CaptureMode;
    /**
     * Flag if crashes should be captured.
     */
    readonly captureCrashes?: CaptureMode;
    /**
     * The multiplicity which should be send back to the server.
     */
    readonly multiplicity?: number;
    /**
     * traffic control percentage.
     */
    readonly trafficControlPercentage?: number;
    /**
     * The application which this configuration applies to.
     */
    readonly applicationId?: string;
    /**
     * Timestamp of the configuration
     */
    readonly timestamp?: number;
    /**
     * Flag if the response is valid. If it is not, all communication stops immediately for the current session.
     */
    readonly valid: boolean;
}
export declare const defaultInvalidStatusResponse: StatusResponse;
//# sourceMappingURL=StatusResponse.d.ts.map