/**
 * Status of configuration
 */
export declare enum Status {
    Error = "ERROR",
    Ok = "OK"
}
/**
 * Represents a status response from dynatrace which will update the state of the current OpenKit application.
 */
export interface StatusResponseJson {
    /**
     * Open Kit related configuration
     */
    readonly mobileAgentConfig?: MobileAgentConfig;
    /**
     * Application related configuration
     */
    readonly appConfig?: AppConfig;
    /**
     * Dynamic configuration
     */
    readonly dynamicConfig?: DynamicConfig;
    /**
     * timestamp of this configuration
     */
    readonly timestamp?: number;
}
export interface MobileAgentConfig {
    /**
     * The maximum beacon size in kilobyte.
     */
    readonly maxBeaconSizeKb?: number;
}
export interface AppConfig {
    /**
     * If capture = Off, all communication should be stopped and no further communication is allowed.
     */
    readonly capture?: number;
    /**
     * Flag if errors should be captured.
     */
    readonly reportErrors?: number;
    /**
     * Flag if crashes should be captured.
     */
    readonly reportCrashes?: number;
    /**
     * The application which this configuration applies to.
     */
    readonly applicationId?: string;
    /**
     * traffic control percentage. Ranges from 1 to 100. Default is 100.
     * 0 is not allowed as it is the same as capture=0.
     */
    readonly trafficControlPercentage?: number;
}
export interface DynamicConfig {
    /**
     * The server id where the next request should be send to.
     */
    readonly serverId?: number;
    /**
     * The multiplicity which should be send back to the server.
     */
    readonly multiplicity?: number;
    /**
     * status of configuration request "OK" or "ERROR"
     */
    readonly status?: Status;
}
//# sourceMappingURL=StatusResponseJson.d.ts.map