import { Action, Session, WebRequestTracer } from '../../api';
import { ConnectionType } from '../../api/ConnectionType';
import { JSONObject } from '../../api/Json';
import { SupplementaryBasicData } from '../beacon/SupplementaryBasicData';
import { OpenKitConfiguration, PrivacyConfiguration } from '../config/Configuration';
import { EventPayload } from '../payload/EventPayload';
import { PayloadBuilder } from '../payload/PayloadBuilder';
import { TimestampProvider } from '../provider/TimestampProvider';
import { PayloadBuilderHelper } from './PayloadBuilderHelper';
export declare class SessionImpl implements Session {
    readonly sessionId: number;
    private readonly config;
    private readonly eventsPayload;
    private readonly supplementaryBasicData;
    readonly payloadData: PayloadBuilderHelper;
    private readonly openActions;
    private readonly logger;
    private _isShutdown;
    constructor(sessionId: number, payloadBuilder: PayloadBuilder, sessionStartTime: number, config: PrivacyConfiguration & OpenKitConfiguration, timestampProvider: TimestampProvider | undefined, eventsPayload: EventPayload, supplementaryBasicData: SupplementaryBasicData);
    /**
     * @inheritDoc
     */
    end(): void;
    /**
     * @inheritDoc
     */
    identifyUser(userTag: string): void;
    /**
     * @inheritDoc
     */
    enterAction(actionName: string): Action;
    /**
     * @inheritDoc
     */
    reportError(name: string, code: number): void;
    /**
     * @inheritDoc
     */
    reportCrash(name: string, message: string, stacktrace: string): void;
    traceWebRequest(url: string): WebRequestTracer;
    /**
     * @inheritDoc
     */
    sendBizEvent(type: string, attributes: JSONObject): void;
    /**
     * @inheritDoc
     */
    sendEvent(name: string, attributes: JSONObject): void;
    reportNetworkTechnology(technology?: string): void;
    reportConnectionType(connectionType?: ConnectionType): void;
    reportCarrier(carrier?: string): void;
    isShutdown(): boolean;
    _getOpenActions(): Action[];
    _endAction(action: Action): void;
    private sendEventHelper;
}
//# sourceMappingURL=SessionImpl.d.ts.map