/**
 * Interface which represents the version used for OpenKit.
 */
export interface OpenKitVersion {
    major: number;
    minor: number;
    build: number;
}
/**
 * Removes an element from a given array.
 * If there are multiple elements of the same instance, only the first is removed.
 *
 * @param array The array to search in
 * @param element The element to remove.
 */
export declare const removeElement: <T>(array: T[], element: T) => void;
export declare const truncate: (str: string, maxLength?: number) => string;
export declare const timeout: (milliseconds: number) => Promise<void>;
export declare const isFinite: (n: number) => boolean;
export declare const isInteger: (n: number) => boolean;
/**
 * Returns the correct version string for OpenKit that is used in the basic data
 *
 * @param major Major version which should be reported
 * @param sprint Sprint version which should be reported
 * @param version Current OK version which should be used for calculating version string
 * @returns Version string which will be used in basic data e.g. 8.205.20100
 */
export declare const getVersionNumber: (major: number, sprint: number, version: OpenKitVersion) => string;
export declare const isNode: boolean;
export declare const isValidHttpUrl: (url: string) => boolean;
//# sourceMappingURL=Utils.d.ts.map